import React from "react";
import {FormButton, restController, RestControllerProps, RestFormLoader, SectionContent} from "../components";
import {ENDPOINT_ROOT} from "../api";
import {Box, List, ListItem, ListItemText} from "@material-ui/core";
import RefreshIcon from "@material-ui/icons/Refresh";
import {getRealTimeString, stringifyTime} from "./Time";
import {HeatingInformationState} from "./types";

// define api endpoint
export const HEATING_ENDPOINT = ENDPOINT_ROOT + "heatinginfo";

type HeatingRestcontollerprops = RestControllerProps<HeatingInformationState>;

class HeatingInformation extends React.Component<HeatingRestcontollerprops> {
    componentDidMount() {
        this.props.loadData();
    }

    render = () => (
        <SectionContent title='Heizung Information' titleGutter>
            <RestFormLoader
                {...this.props}
                render={props => (
                    <>
                        <List>
                            <ListItem>
                                <ListItemText
                                    primary="Heizung lief zuletzt:"
                                    secondary={props.data.lastheating !== 0 ?
                                        <>
                                            vor {stringifyTime(props.data.lastheating)}<br/>
                                            {getRealTimeString(props.data.lastheating)}
                                        </> : "noch nie!"}
                                />
                            </ListItem>
                            <ListItem>
                                <ListItemText
                                    primary="Letze Heizdauer:"
                                    secondary={props.data.lastheatduration === 0 ? "-" : props.data.lastheatduration === -1 ? "läuft gerade!" : stringifyTime(props.data.lastheatduration)}
                                />
                            </ListItem>
                            <ListItem>
                                <ListItemText
                                    primary="Temperatur/Luftfeuchtigkeit:"
                                    secondary={(props.data.temp !== -1 ? props.data.temp + "C" : "Auslesefehler!") + " / " + (props.data.hum !== -1 ? props.data.hum + "%" : "Auslesefehler!")}
                                />
                            </ListItem>
                        </List>
                        <Box display="flex" flexWrap="wrap">
                            <Box flexGrow={1} padding={1}>
                                <FormButton startIcon={<RefreshIcon/>} variant="contained" color="secondary"
                                            onClick={this.props.loadData}>
                                    Refresh
                                </FormButton>
                            </Box>
                        </Box>
                    </>
                )}
            />
        </SectionContent>
    );
}

export default restController(HEATING_ENDPOINT, HeatingInformation);